@@ -9,3 +9,5 @@ from instascrape.scrapers.post import *
 from instascrape.scrapers.profile import *
 from instascrape.scrapers.comment import *
 from instascrape.scrapers.location import *
+from instascrape.scrapers.reel import *
+from instascrape.scrapers.igtv import *
