@@ -7,16 +7,11 @@ from instascrape.core._mappings import _PostMapping, _ProfileMapping
 from instascrape.core._static_scraper import _StaticHtmlScraper
 from instascrape.scrapers.post import Post
 
+warnings.simplefilter("always", DeprecationWarning)
+
 
 class Profile(_StaticHtmlScraper):
-    """
-    Scraper for an Instagram profile page
-
-    Methods
-    -------
-    from_username(shortcode: str) -> Post
-        Factory method that returns a Profile object from a shortcode
-    """
+    """Scraper for an Instagram profile page"""
 
     _Mapping = _ProfileMapping
 
@@ -35,16 +30,20 @@ class Profile(_StaticHtmlScraper):
             List containing the recent 12 posts and their available data
         """
         if amt > 12:
-            raise IndexError(f"{amt} is too large, 12 is max available posts")
+            raise IndexError(f"{amt} is too large, 12 is max available posts. Getting more posts will require an out-of-the-box extension.")
         posts = []
-        post_arr = self.json_dict["entry_data"]["ProfilePage"][0]["graphql"]["user"]["edge_owner_to_timeline_media"][
-            "edges"
-        ]
+        try:
+            post_arr = self.json_dict["entry_data"]["ProfilePage"][0]["graphql"]["user"]["edge_owner_to_timeline_media"][
+                "edges"
+            ]
+        except TypeError:
+            raise ValueError("Can't return posts without first scraping the Profile. Call the scrape method on your object first.")
+
         for post in post_arr[:amt]:
             json_dict = post["node"]
             mapping = _PostMapping.post_from_profile_mapping()
             post = Post(json_dict)
-            post.load(mapping=mapping)
+            post.scrape(mapping=mapping)
             posts.append(post)
         return posts
 
@@ -52,8 +51,9 @@ class Profile(_StaticHtmlScraper):
         return f"https://www.instagram.com/{suburl}/"
 
     @classmethod
-    def from_username(self, username):
-        warnings.simplefilter('always', DeprecationWarning)
+    def from_username(cls, username):
         warnings.warn(
-            'This will be deprecated in the near future. You no longer need to use from_username, simply pass username as argument to Profile', DeprecationWarning)
+            "This will be deprecated in the near future. You no longer need to use from_username, simply pass username as argument to Profile",
+            DeprecationWarning,
+        )
         return Profile(username)
